==> haskell-quickcheck-assertions-0.3.0-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-HwVgsXH936UE9FvyGi3Ndm
key: quickcheck-assertions-0.3.0-HwVgsXH936UE9FvyGi3Ndm
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 0ea99330fcf54149d88aee80d41bc019
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-HwVgsXH936UE9FvyGi3Ndm
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=9f6b114ae6eb47237e10ea290c9398cc
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=7f72f065bf630927a07ec77462e0c52e
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-6NiZMnZCtHCJ0urVrFkkPF
key: quickcheck-assertions-0.3.0-6NiZMnZCtHCJ0urVrFkkPF
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 4d747822733551f8b4125b7935fae808
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-6NiZMnZCtHCJ0urVrFkkPF
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=9f6b114ae6eb47237e10ea290c9398cc
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=7f72f065bf630927a07ec77462e0c52e
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
